use Test::More tests => 15;

use strict;
use warnings;
$XML::SAX::ParserPackage = $XML::SAX::ParserPackage ||= $ENV{'NOH_ParserPackage'};

use_ok( 'Net::OAIPMH::Harvester' );

## a good call

my $repo = 'https://services.phaidra.univie.ac.at/api/oai';
my $h = new_ok('Net::OAIPMH::Harvester' => [ baseURL => $repo ]);

my $i = $h->identify();
isa_ok( $i, 'Net::OAIPMH::Identify', 'identity()' );

SKIP: {
    my $HTE = HTE($i, $repo);
    skip $HTE, 10 if $HTE;

    ok( ! $i->errorCode(), 'errorCode()' );
    ok( ! $i->errorString(), 'errorString()' );

    subtest 'OAI request/response' => sub {
        plan tests => 3;
        like($i->responseDate(), qr/^\d{4}-\d\d-\d\dT\d\d:\d\d:\d\dZ$/, 'OAI responseDate element' );
        my ($it, %ia) = $i->request();
        is($it, $repo, 'OAI response element text' );
        is($ia{ verb }, 'Identify', 'OAI verb' );
      };

    like( $i->repositoryName(), qr/University of Vienna Phaidra/, 'repositoryName()');
    like( $i->protocolVersion(), qr/^2\.0$/, 'protocolVersion()' );
    like( $i->earliestDatestamp(), qr/^\d{4}-\d{2}-\d{2}/, 'earliestDatestamp()' );
    like( $i->deletedRecord(), qr/no|persistent|transient/, 'deletedRecord()' );
    like( $i->granularity(), qr/^YYYY/, 'granularity()' );

    my $email = $i->adminEmail();
    my @emails = $i->adminEmail();
    like( $email, qr/@/, 'adminEmail() scalar context' );
    like( $emails[0], qr/@/, 'adminEmail() list context' ); 

## make sure we can call them, even though they are optional
    my $compression = $i->compression();
    my @compressions = $i->compression();
}

## make sure we don't get stuff from sub descriptions
$repo = 'https://services.phaidra.univie.ac.at/api/oai';
$h = new_ok('Net::OAIPMH::Harvester' => [ baseURL => $repo ]);
$i = $h->identify();

SKIP: {
    my $HTE = HTE($i, $repo);
    skip $HTE, 1 if $HTE;

    is( $i->repositoryName(), 
        'University of Vienna Phaidra',
        'do not extract sub descriptions and run them together'
    );
}

sub HTE {
    my ($r, $url) = @_;
    my $hte;
    if ( my $e = $r->HTTPError() ) {
        $hte = "HTTP Error ".$e->status_line;
	$hte .= " [Retry-After: ".$r->HTTPRetryAfter()."]" if $e->code() == 503;
	diag("LWP condition accessing $url:\n$hte");
        note explain $e;
      }
   return $hte;
}

